# Table of Contents

- [setup-in-sap-leanix](<./setup-in-sap-leanix.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Setup in SAP LeanIX](<./Setup-in-SAP-LeanIX.md>)
  - [Adding a Configuration](<./Setup-in-SAP-LeanIX/Adding-a-Configuration.md>)
  - [Configuration Page Overview](<./Setup-in-SAP-LeanIX/Configuration-Page-Overview.md>)
  - [Credential Configuration](<./Setup-in-SAP-LeanIX/Credential-Configuration.md>)
  - [Partial Sync Mode](<./Setup-in-SAP-LeanIX/Partial-Sync-Mode.md>)
  - [Authentication Options for ServiceNow](<./Setup-in-SAP-LeanIX/Authentication-Options-for-ServiceNow.md>)
  - [Synchronization](<./Setup-in-SAP-LeanIX/Synchronization.md>)
  - [Manual Full Sync](<./Setup-in-SAP-LeanIX/Manual-Full-Sync.md>)
  - [Scheduled Full Sync](<./Setup-in-SAP-LeanIX/Scheduled-Full-Sync.md>)
  - [Partial Sync](<./Setup-in-SAP-LeanIX/Partial-Sync.md>)
  - [Aggregation and Linkage of Software Records](<./Setup-in-SAP-LeanIX/Aggregation-and-Linkage-of-Software-Records.md>)
  - [Configuring Mappings](<./Setup-in-SAP-LeanIX/Configuring-Mappings.md>)
  - [Field Mapping](<./Setup-in-SAP-LeanIX/Field-Mapping.md>)
  - [AI-Generated Field Mapping Suggestions](<./Setup-in-SAP-LeanIX/AI-Generated-Field-Mapping-Suggestions.md>)
  - [Mapping Relations](<./Setup-in-SAP-LeanIX/Mapping-Relations.md>)
